--[[

Author: Faerosong of Winterhoof

Sapped!

This addon provides battlefield intelligence both for you and your team.  It alerts when you are sapped
so they can prepare to strike or to know where they need to provide support.

Inspired by
SaySapped by Bitbyte of Icecrown

Usage: go to Interface->Add-ons->Sapped!

Changelog
2012.11.26.001
Updated for patch 5.1

2012.08.28.001
Updated for patch 5.0.4

2012.05.17.001
Changed the sound again

2012.05.16.001
Added RAID Frame Warning

2012.05.12.001
Changed to a more distinctive sound
First official release

2012.05.11.001
Added sound option
Moved the addon config checkboxes around a little
Added a "Yell" option

2012.05.09.001
First beta release

2012.05.07.001
Cleaned up code and fixed bugs related to boolean values

2012.05.04.003
Added code to stop trying to send text to non-existant channels

2012.05.04.002
Fixed bugs and optimized and also it works now.

2012.05.04.001
First Alpha Release

]]--

local Version = "2012.05.17.001"

SappedOptions = {};
SappedOptions.panel = CreateFrame( "Frame", "SappedPanel");
SappedOptions.panel.name = L_SAPPED;
InterfaceOptions_AddCategory(SappedOptions.panel);

local IntroMessageHeader = SappedOptions.panel:CreateFontString(nil, "ARTWORK","GameFontNormalLarge");
IntroMessageHeader:SetPoint("TOPLEFT", 10, -10);
IntroMessageHeader:SetText(L_SAPPED..Version);

local EnabledCheck = CreateFrame("CheckButton", "Sapped_EnableCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
EnabledCheck:SetPoint("TOPLEFT",10,-35)	
EnabledCheck.Text = EnabledCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
EnabledCheck.Text:SetPoint("LEFT", EnabledCheck, "RIGHT", 0)
EnabledCheck.Text:SetText(L_ENABLED)
EnabledCheck.tooltipText = L_ENABLETIP
EnabledCheck:SetScript("OnClick", function(self, button, down)
  EnabledBool = EnabledCheck:GetChecked()
  if (EnabledBool == nil) then
    EnabledBool = 0
  end
end)

local SayCheck = CreateFrame("CheckButton", "Sapped_SayCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
SayCheck:SetPoint("TOPLEFT",10,-95)	
SayCheck.Text = SayCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
SayCheck.Text:SetPoint("LEFT", SayCheck, "RIGHT", 0)
SayCheck.Text:SetText(L_SAY)
SayCheck.tooltipText = L_SAYTIP
SayCheck:SetScript("OnClick", function(self, button, down)
  SayBool = SayCheck:GetChecked()
  if (SayBool == nil) then
    SayBool = 0
  end
end)

local PartyCheck = CreateFrame("CheckButton", "Sapped_PartyCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
PartyCheck:SetPoint("TOPLEFT",10,-125)	
PartyCheck.Text = PartyCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
PartyCheck.Text:SetPoint("LEFT", PartyCheck, "RIGHT", 0)
PartyCheck.Text:SetText(L_PARTY)
PartyCheck.tooltipText = L_PARTYTIP
PartyCheck:SetScript("OnClick", function(self, button, down)
  PartyBool = PartyCheck:GetChecked()
  if (PartyBool == nil) then
    PartyBool = 0
  end
end)

local BattlegroundCheck = CreateFrame("CheckButton", "Sapped_BattlegroundCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
BattlegroundCheck:SetPoint("TOPLEFT",10,-155)	
BattlegroundCheck.Text = BattlegroundCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
BattlegroundCheck.Text:SetPoint("LEFT", BattlegroundCheck, "RIGHT", 0)
BattlegroundCheck.Text:SetText(L_BATTLEGROUND)
BattlegroundCheck.tooltipText = L_BATTLEGROUNDTIP
BattlegroundCheck:SetScript("OnClick", function(self, button, down)
  BattlegroundBool = BattlegroundCheck:GetChecked()
  if (BattlegroundBool == nil) then
    BattlegroundBool = 0
  end
end)

local RAIDCheck = CreateFrame("CheckButton", "Sapped_RAIDCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
RAIDCheck:SetPoint("TOPLEFT",10,-185)	
RAIDCheck.Text = RAIDCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
RAIDCheck.Text:SetPoint("LEFT", RAIDCheck, "RIGHT", 0)
RAIDCheck.Text:SetText(L_RAID)
RAIDCheck.tooltipText = L_RAIDTIP
RAIDCheck:SetScript("OnClick", function(self, button, down)
  RAIDBool = RAIDCheck:GetChecked()
  if (RAIDBool == nil) then
    RAIDBool = 0
  end
end)

local YellCheck = CreateFrame("CheckButton", "Sapped_YellCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
YellCheck:SetPoint("TOPLEFT",10,-215)	
YellCheck.Text = YellCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
YellCheck.Text:SetPoint("LEFT", YellCheck, "RIGHT", 0)
YellCheck.Text:SetText(L_YELL)
YellCheck.tooltipText = L_YELLTIP
YellCheck:SetScript("OnClick", function(self, button, down)
  YellBool = YellCheck:GetChecked()
  if (YellBool == nil) then
    YellBool = 0
  end
end)

local SoundCheck = CreateFrame("CheckButton", "Sapped_SoundCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
SoundCheck:SetPoint("TOPLEFT",10,-275)	
SoundCheck.Text = SoundCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
SoundCheck.Text:SetPoint("LEFT", SoundCheck, "RIGHT", 0)
SoundCheck.Text:SetText(L_SOUND)
SoundCheck.tooltipText = L_SOUNDTIP
SoundCheck:SetScript("OnClick", function(self, button, down)
  SoundBool = SoundCheck:GetChecked()
  if (SoundBool == nil) then
    SoundBool = 0
  end
end)

local RAIDWarnCheck = CreateFrame("CheckButton", "Sapped_RAIDWarnCheck", SappedOptions.panel, "ChatConfigCheckButtonTemplate")
RAIDWarnCheck:SetPoint("TOPLEFT",10,-305)	
RAIDWarnCheck.Text = RAIDWarnCheck:CreateFontString(nil, "BACKGROUND","GameFontNormal")
RAIDWarnCheck.Text:SetPoint("LEFT", RAIDWarnCheck, "RIGHT", 0)
RAIDWarnCheck.Text:SetText(L_RAIDWARN)
RAIDWarnCheck.tooltipText = L_RAIDWARNTIP
RAIDWarnCheck:SetScript("OnClick", function(self, button, down)
  RAIDWarnBool = RAIDWarnCheck:GetChecked()
  if (RAIDWarnBool == nil) then
    RAIDWarnBool = 0
  end
end)

local Sapped = CreateFrame("Frame")
Sapped.playername = UnitName("player")
Sapped:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
Sapped:RegisterEvent("ADDON_LOADED");

Sapped:SetScript("OnEvent", function(...)

            if (select(2,...) == "ADDON_LOADED") then
              if (EnabledBool == nil) then
                  EnabledBool = 1
                end
              EnabledCheck:SetChecked(EnabledBool)
	
              if (SayBool == nil) then
                  SayBool = 1
                end
              SayCheck:SetChecked(SayBool)

              if (PartyBool == nil) then
                  PartyBool = 0
                end
              PartyCheck:SetChecked(PartyBool)

              if (BattlegroundBool == nil) then
                  BattlegroundBool = 1
                end
              BattlegroundCheck:SetChecked(BattlegroundBool)

              if (RAIDBool == nil) then
                  RAIDBool = 0
                end
              RAIDCheck:SetChecked(RAIDBool)

              if (YellBool == nil) then
                  YellBool = 0
                end
              YellCheck:SetChecked(YellBool)

              if (SoundBool == nil) then
                  SoundBool = 1
                end
              SoundCheck:SetChecked(SoundBool)

              if (RAIDWarnBool == nil) then
                  RAIDWarnBool = 0
                end
              RAIDWarnCheck:SetChecked(RAIDWarnBool)
            end

            if ((EnabledBool == 1) and (select(14,...) == 6770)
	and (select(11,...) == Sapped.playername)
	and (select(4,...) == "SPELL_AURA_APPLIED" or select(4,...) == "SPELL_AURA_REFRESH"))
	then
                local subzone = GetSubZoneText()

                if (RAIDWarnBool == 1) then
                  RaidNotice_AddMessage(RaidWarningFrame, L_SAPPED, ChatTypeInfo["RAID_WARNING"])
	 end

                if (SoundBool == 1) then
                  PlaySoundFile("Interface\\AddOns\\Sapped!\\Sounds\\sapped.mp3")
                end

                if (SayBool == 1) then
                  SendChatMessage(L_SAPPED, "SAY")
                end
  
                if (PartyBool == 1) and (subzone ~= "") and (GetNumPartyMembers() > 0) then
                  SendChatMessage(L_SAPPEDAT .. subzone .. L_BY .. select(7,...), "PARTY")
                end

                if (BattlegroundBool == 1) and (subzone ~= "") and (GetBattlefieldInstanceRunTime() > 0) then
                  SendChatMessage(L_SAPPEDAT .. subzone .. L_BY .. select(7,...), "BATTLEGROUND")
                end

                if (RAIDBool == 1) and (subzone ~= "") and UnitInRaid("player") then
                  SendChatMessage(L_SAPPEDAT .. subzone .. L_BY .. select(7,...), "RAID")
                end
  
                if (YellBool == 1) and (subzone ~= "") then
                  SendChatMessage(L_SAPPEDAT .. subzone .. L_BY .. select(7,...), "YELL")
                end
                                 
                DEFAULT_CHAT_FRAME:AddMessage(L_SAPPEDBY .. (select(7,...) or L_UNKNOWN))
	end
end)

DEFAULT_CHAT_FRAME:AddMessage(L_SAPPED .. Version .. L_LOADED)
